@@ -55,9 +55,12 @@ import java.io.InputStream;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.amazonaws.ClientConfiguration;
+import com.amazonaws.auth.AWSStaticCredentialsProvider;
 import com.amazonaws.auth.BasicAWSCredentials;
+import com.amazonaws.client.builder.AwsClientBuilder.EndpointConfiguration;
 import com.amazonaws.regions.Regions;
 import com.amazonaws.services.s3.AmazonS3Client;
+import com.amazonaws.services.s3.AmazonS3ClientBuilder;
 import com.amazonaws.services.s3.S3ClientOptions;
 import com.amazonaws.services.s3.model.ObjectMetadata;
 import com.amazonaws.services.s3.model.Region;
@@ -116,27 +119,32 @@ public class S3StorageImpl extends AbstractStorage {
         if (signerOverride != null && !signerOverride.isEmpty()) {
             clientConfiguration.setSignerOverride(signerOverride);
         }
-        s3Client = new AmazonS3Client(credentials, clientConfiguration);
-        s3Client.setS3ClientOptions(new S3ClientOptions().withPathStyleAccess(true));
+        AmazonS3ClientBuilder builder = AmazonS3ClientBuilder.standard()
+            .withCredentials(new AWSStaticCredentialsProvider(credentials))
+            .withClientConfiguration(clientConfiguration);
 
         /*
          * Configure client
          */
+        builder.setPathStyleAccessEnabled(true);
+
         if (Strings.isNotEmpty(endpoint)) {
-            s3Client.setEndpoint(endpoint);
+            builder.setEndpointConfiguration(new EndpointConfiguration(endpoint, region));
         } else {
             try {
-                s3Client.setRegion(com.amazonaws.regions.Region.getRegion(Regions.fromName(region)));
+                builder.withRegion(Regions.fromName(region));
             } catch (IllegalArgumentException e) {
                 logger.error("Error at s3Client setRegion", e);
             }
         }
 
+        s3Client = (AmazonS3Client) builder.build();
+
         /*
          * Check if configured S3 bucket exists, otherwise create.
          */
         if (!s3Client.doesBucketExist(bucketName)) {
-            s3Client.createBucket(bucketName, Region.fromValue(region));
+            s3Client.createBucket(bucketName);
         }
     }
 
@@ -232,6 +240,16 @@ public class S3StorageImpl extends AbstractStorage {
         }
     }
 
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.storage.Storage#objectExists(java.lang.String)
+     */
+    @Override
+    public boolean objectExists(String location) throws OXException {
+        /* not implemented yet*/
+        return true;
+    }
+
     /*
      * (non-Javadoc)
      *
